@@ -51,7 +51,7 @@ namespace xt
      *
      * @tparam EC The type of the container holding the elements.
      * @tparam SC The type of the containers holding the shape and the strides.
-     * @sa xarray
+     * @sa xarray,  move_reshape
      */
     template <class EC, class SC>
     class xarray_container : public xstrided_container<xarray_container<EC, SC>>,
@@ -101,12 +101,17 @@ namespace xt
 
     private:
 
+        xarray_container(EC&& data, const shape_type& shape, const strides_type& strides);
+
         container_type m_data;
 
         container_type& data_impl() noexcept;
         const container_type& data_impl() const noexcept;
 
         friend class xcontainer<xarray_container<EC, SC>>;
+
+        template <class EC2, class SC2>
+        friend xarray_container<EC2, SC2> move_reshape(xarray_container<EC2, SC2>&& data, const SC2& shape, const SC2& strides);
     };
 
     /******************************
@@ -147,6 +152,7 @@ namespace xt
      *
      * @tparam EC The container type to adapt.
      * @tparam SC The type of the containers holding the shape and the strides.
+     * @sa move_reshape
      */
     template <class EC, class SC>
     class xarray_adaptor : public xstrided_container<xarray_adaptor<EC, SC>>,
@@ -179,6 +185,8 @@ namespace xt
 
     private:
 
+        xarray_adaptor(EC&& data, const shape_type& shape, const strides_type& strides);
+
         container_type& m_data;
 
         container_type& data_impl() noexcept;
@@ -189,8 +197,30 @@ namespace xt
 
         friend class xcontainer<xarray_adaptor<EC, SC>>;
         friend class xadaptor_semantic<xarray_adaptor<EC, SC>>;
+
+        template <class EC2, class SC2>
+        friend xarray_adaptor<EC2, SC2> move_reshape(xarray_adaptor<EC2, SC2>&& data, const SC2& shape, const SC2& strides);
     };
 
+    /****************
+     * move_reshape *
+     ****************/
+
+    template <template <class, class> class C, class EC, class SC>
+    C<EC, SC> move_reshape(C<EC, SC>& rhs, const SC& shape);
+
+    template <template <class, class> class C, class EC, class SC>
+    C<EC, SC> move_reshape(C<EC, SC>&& rhs, const SC& shape);
+
+    template <template <class, class> class C, class EC, class SC>
+    C<EC, SC> move_reshape(C<EC, SC>& rhs, const SC& shape, const SC& strides);
+
+    template <class EC, class SC>
+    xarray_container<EC, SC> move_reshape(xarray_container<EC, SC>&& rhs, const SC& shape, const SC& strides);
+
+    template <class EC, class SC>
+    xarray_adaptor<EC, SC> move_reshape(xarray_adaptor<EC, SC>&& rhs, const SC& shape, const SC& strides);
+
     /***********************************
      * xarray_container implementation *
      ***********************************/
@@ -369,6 +399,13 @@ namespace xt
     }
     //@}
 
+    template <class EC, class SC>
+    inline xarray_container<EC, SC>::xarray_container(EC&& data, const shape_type& shape, const strides_type& strides)
+        : base_type(), m_data(std::move(data))
+    {
+        base_type::reshape(shape, strides);
+    }
+
     template <class EC, class SC>
     inline auto xarray_container<EC, SC>::data_impl() noexcept -> container_type&
     {
@@ -459,6 +496,13 @@ namespace xt
     }
     //@}
 
+    template <class EC, class SC>
+    inline xarray_adaptor<EC, SC>::xarray_adaptor(EC&& data, const shape_type& shape, const strides_type& strides)
+        : base_type(), m_data(data)
+    {
+        base_type::reshape(shape, strides);
+    }
+
     template <class EC, class SC>
     inline auto xarray_adaptor<EC, SC>::data_impl() noexcept -> container_type&
     {
@@ -482,6 +526,64 @@ namespace xt
         m_data.resize(tmp.size());
         std::copy(tmp.data().cbegin(), tmp.data().cend(), m_data.begin());
     }
+
+    /*******************************
+     * move_reshape implementation *
+     *******************************/
+
+    template <template <class, class> class C, class EC, class SC>
+    inline C<EC, SC> move_reshape(C<EC, SC>& rhs, const SC& shape)
+    {
+        return move_reshape(std::move(rhs), shape);
+    }
+
+    template <template <class, class> class C, class EC, class SC>
+    inline C<EC, SC> move_reshape(C<EC, SC>&& rhs, const SC& shape)
+    {
+        SC strides(shape.size());
+        compute_strides(shape, layout::row_major, strides);
+        return move_reshape(std::move(rhs), shape, strides);
+    }
+
+    template <template <class, class> class C, class EC, class SC>
+    inline C<EC, SC> move_reshape(C<EC, SC>& rhs, const SC& shape, const SC& strides)
+    {
+        return move_reshape(std::move(rhs), shape, strides);
+    }
+
+    /**
+     * Moves the data of the specified multidimensional array into a new multidimensional array
+     * that is reshaped with the given shape and strides. The original array is invalidated.
+     * This method should not be used directly, it is provided for consitency with xtensor. The
+     * reshape method should be used instead.
+     *
+     * @param rhs the multidimensional array to reshape. May be passed as lvalue or rvalue reference.
+     * @param shape the new shape.
+     * @param strides the new strides. If omitted, the strides are computed so the new array
+     *                has a row major layout.
+     */
+    template <class EC, class SC>
+    inline xarray_container<EC, SC> move_reshape(xarray_container<EC, SC>&& rhs, const SC& shape, const SC& strides)
+    {
+        return xarray_container<EC, SC>(std::move(rhs.m_data), shape, strides);
+    }
+
+    /**
+     * Moves the data of the specified multidimensional array adaptor into a new multidimensional array
+     * and reshapes it with the given shape and strides. The original array adapter is invalidated.
+     * This method should not be used directly, it is provided for consitency with xtensor. The reshape
+     * method should be used instead.
+     *
+     * @param rhs the mutldimensional arrat adaptor to reshape. May be passed as lvalue or rvalue reference.
+     * @param shape the new shape.
+     * @param strides the new strides. If omitted, the strides are computed so the new multidimensional array
+     *                adaptor has a row major layout.
+     */
+    template <class EC, class SC>
+    inline xarray_adaptor<EC, SC> move_reshape(xarray_adaptor<EC, SC>&& rhs, const SC& shape, const SC& strides)
+    {
+        return xarray_adaptor<EC, SC>(std::move(rhs.m_data), shape, strides);
+    }
 }
 
 #endif
