@@ -17,7 +17,7 @@
 #include <type_traits>
 
 // Compiler bug workaround
-#if __GNUC__ && !defined(__APPLE__) && (__GNUC__ < 5 || (__GNUC__ == 5 && __GNUC_MINOR__ < 1)) 
+#if (__GNUC__ && (__GNUC__ < 5 || (__GNUC__ == 5 && __GNUC_MINOR__ < 1)) ) && !(defined(__APPLE__)) || defined(X_OLD_CLANG)
 #define is_trivially_default_constructible has_trivial_default_constructor
 #endif
 
